# 🌐 Blue-GEO

AI for precise geospatial data analysis and visualization.

```bash
pip install blue-geo
```

--table--

---

[![PyPI version](https://img.shields.io/pypi/v/blue-geo.svg)](https://pypi.org/project/blue-geo/)

📜 [metadata](./metadata.yaml)

---

To use on [AWS SageMaker](https://aws.amazon.com/sagemaker/) replace `<plugin-name>` with the name of the plugin and follow [these instructions](https://github.com/kamangir/notebooks-and-scripts/blob/main/SageMaker.md).

--signature--